@@ -93,7 +93,10 @@ def test_get_groups_with_attrs(mock_connection, mocker):
         ["groupname", "url", "unknown"], page_number=1, page_size=0
     )
     mock_connection.search_ext.assert_called_once()
-    mock_connection.search_ext.call_args[1]["attrlist"] == ["cn", "fasUrl"]
+    assert mock_connection.search_ext.call_args[1]["attrlist"] == [
+        "cn",
+        "fasurl",
+    ]
 
 
 def test_get_group(mock_connection):
@@ -305,7 +308,10 @@ def test_get_user_with_attrs(mock_connection, mocker):
     ldap.get_user("admin", ["username", "surname"])
 
     mock_connection.search_ext.assert_called_once()
-    mock_connection.search_ext.call_args[1]["attrlist"] == ["uid", "sn"]
+    assert mock_connection.search_ext.call_args[1]["attrlist"] == [
+        "uid",
+        "sn",
+    ]
 
 
 def test_get_user_not_found(mock_connection):
@@ -393,8 +399,6 @@ def test_search_users(mock_connection):
         username="dummy",
         email="dummy",
         ircnick="dummy-1@example.test",
-        givenname="",
-        surname="",
         attrs=None,
         page_number=1,
         page_size=0,
@@ -420,6 +424,44 @@ def test_search_users(mock_connection):
     assert result == expected
 
 
+@pytest.mark.parametrize(
+    "query,expected_filter",
+    [
+        ({"username": ""}, ""),
+        ({"username": "something"}, "(uid=*something*)"),
+        ({"username__exact": "something"}, "(uid=something)"),
+        ({"human_name": "something"}, "(displayName=*something*)"),
+        ({"human_name__exact": "something"}, "(displayName=something)"),
+        (
+            {"github_username__exact": "something"},
+            "(fasGitHubUsername=something)",
+        ),
+        (
+            {"creation__before": datetime.datetime(2042, 1, 1)},
+            "(fasCreationTime<=20420101000000Z)",
+        ),
+    ],
+)
+def test_search_users_filters(
+    mock_connection, mocker, query, expected_filter
+):
+    mock_connection.result3 = _single_page_result_factory([])
+    mock_connection.search_ext = mocker.Mock(return_value=1)
+
+    ldap = LDAP("ldap://dummy.com", basedn="dc=example,dc=test")
+    ldap.search_users(
+        attrs=None,
+        page_number=1,
+        page_size=0,
+        **query,
+    )
+    mock_connection.search_ext.assert_called_once()
+    assert (
+        mock_connection.search_ext.call_args[0][2]
+        == f"(&(&(objectClass=fasUser)(!(nsAccountLock=TRUE)))(&{expected_filter}))"
+    )
+
+
 def test_get_paged_search_filters(mock_connection):
     mocked = []
 
@@ -432,10 +474,6 @@ def test_get_paged_search_filters(mock_connection):
             page_number=2,
             page_size=3,
             username="something",
-            email=None,
-            ircnick=None,
-            givenname=None,
-            surname=None,
         )
 
     called_filters = [call[1]["filters"] for call in do_search.call_args_list]
@@ -496,6 +534,7 @@ def test_get_paged_search_no_results(mock_connection):
             ircnick="something",
             givenname="some",
             surname="thing",
+            human_name="something",
         )
 
     called_filters = [call[1]["filters"] for call in do_search.call_args_list]
@@ -503,7 +542,7 @@ def test_get_paged_search_no_results(mock_connection):
         (
             "(&(&(objectClass=fasUser)(!(nsAccountLock=TRUE)))(&(uid=*something*)"
             "(mail=something@example.test)(fasIRCNick=*something*)"
-            "(givenName=*some*)(sn=*thing*)))"
+            "(givenName=*some*)(sn=*thing*)(displayName=*something*)))"
         )
     ]
     expected = LDAPResult(
